summaryrefslogtreecommitdiffstats
path: root/tests/utils/tacker-setup.sh
diff options
context:
space:
mode:
authorblsaws <bryan.sullivan@att.com>2016-09-06 16:11:59 -0700
committerblsaws <bryan.sullivan@att.com>2016-09-06 16:11:59 -0700
commit70019f0c67b127e22ff17287c5fb2fa57d5c9bc0 (patch)
tree2ddb81a589c404e702800653ee11b03e53da32bb /tests/utils/tacker-setup.sh
parent134ed14ddcda97ff8ac7ff2d473d405b6d31f407 (diff)
Updates in further testing
JIRA: MODELS-23 Change-Id: I55418cc967fdf5e59d60304d2513dbe1e80b7dcc Signed-off-by: blsaws <bryan.sullivan@att.com>
Diffstat (limited to 'tests/utils/tacker-setup.sh')
-rw-r--r--tests/utils/tacker-setup.sh121
1 files changed, 94 insertions, 27 deletions
diff --git a/tests/utils/tacker-setup.sh b/tests/utils/tacker-setup.sh
index 3037131..4e60632 100644
--- a/tests/utils/tacker-setup.sh
+++ b/tests/utils/tacker-setup.sh
@@ -19,11 +19,12 @@
# Status: this is a work in progress, under test.
#
# How to use:
-# $ bash tacker-setup.sh [tacker-cli|tacker-api] [ 1 || 2 ]
+# $ bash tacker-setup.sh [tacker-cli|tacker-api] [init|setup|clean]
# tacker-cli: use Tacker CLI
# tacker-api: use Tacker RESTful API
# 1: Initial setup of the docker container
# 2: Setup of Tacker in the docker container
function setenv () {
if [ "$dist" == "Ubuntu" ]; then
@@ -91,7 +92,7 @@ function get_external_net () {
dist=`grep DISTRIB_ID /etc/*-release | awk -F '=' '{print $2}'`
case "$2" in
- "1")
+ "init")
# STEP 1: Create the Tacker container and launch it
echo "$0: Copy this script to /tmp/tacker"
mkdir /tmp/tacker
@@ -106,7 +107,7 @@ case "$2" in
# xenial is needed for python 3.5
sudo docker pull ubuntu:xenial
sudo service docker start
- sudo docker run -it -d -v /tmp/tacker/:/tmp/tacker ubuntu:xenial /bin/bash
+ sudo docker run -it -d -v /tmp/tacker/:/tmp/tacker --name tacker ubuntu:xenial /bin/bash
else
# Centos
echo "Centos-based install"
@@ -122,16 +123,27 @@ EOF
# xenial is needed for python 3.5
sudo docker pull ubuntu:xenial
sudo service docker start
- sudo docker run -i -t -d -v /tmp/tacker/:/tmp/tacker ubuntu:xenial /bin/bash
+ sudo docker run -i -t -d -v /tmp/tacker/:/tmp/tacker --name tacker ubuntu:xenial /bin/bash
+ echo $(sudo docker ps -a | awk "/tacker/ { print \$1 }")
fi
exit 0
;;
- "2")
+ "setup")
+ ;;
+ "clean")
+ source /tmp/tacker/admin-openrc.sh
+ openstack endpoint delete $(openstack endpoint list | awk "/tacker/ { print \$2 }")
+ openstack user delete $(openstack user list | awk "/tacker/ { print \$2 }")
+ openstack service delete $(openstack service list | awk "/tacker/ { print \$2 }")
+ sudo docker stop $(sudo docker ps -a | awk "/tacker/ { print \$1 }")
+ sudo docker rm $(sudo docker ps -a | awk "/tacker/ { print \$1 }")
+ exit 0
;;
*)
- echo "usage: bash tacker-setup.sh [tacker-cli|tacker-api] [ 1 || 2 ]"
- echo "1: Initial setup of the docker container"
- echo "2: Setup of Tacker in the docker container"
+ echo "usage: bash tacker-setup.sh [tacker-cli|tacker-api] [init|setup|clean]"
+ echo "init: Initialize docker container"
+ echo "setup: Setup of Tacker in the docker container"
+ echo "clean: remove Tacker service"
exit 1
esac
@@ -147,10 +159,14 @@ if [ "$dist" == "Ubuntu" ]; then
apt-get install -y openssh-server
apt-get install -y git
apt-get install -y apg
+ apt-get install -y libffi-dev
+ apt-get install -y libssl-dev
export MYSQL_PASSWORD=$(/usr/bin/apg -n 1 -m 16 -c cl_seed)
+ echo $MYSQL_PASSWORD >~/mysql
debconf-set-selections <<< 'mysql-server mysql-server/root_password password '$MYSQL_PASSWORD
debconf-set-selections <<< 'mysql-server mysql-server/root_password_again password '$MYSQL_PASSWORD
apt-get -q -y install mysql-server python-mysqldb
+ service mysql restart
fi
cd /tmp/tacker
@@ -158,24 +174,17 @@ cd /tmp/tacker
echo "$0: create Tacker database"
mysql --user=root --password=$MYSQL_PASSWORD -e "CREATE DATABASE tacker; GRANT ALL PRIVILEGES ON tacker.* TO 'root@localhost' IDENTIFIED BY '"$MYSQL_PASSWORD"'; GRANT ALL PRIVILEGES ON tacker.* TO 'root'@'%' IDENTIFIED BY '"$MYSQL_PASSWORD"';"
-echo "$0: Install dependencies - generic"
-pip install --upgrade pip virtualenv
-
echo "$0: Upgrage pip again - needs to be the latest version due to errors found in earlier testing"
-pip install --upgrade
+pip install --upgrade pip
echo "$0: install python-openstackclient python-glanceclient"
pip install --upgrade python-openstackclient python-glanceclient python-neutronclient keystonemiddleware
-echo "$0: Create virtualenv"
-virtualenv /tmp/tacker/venv
-source /tmp/tacker/venv/bin/activate
-
echo "$0: Setup admin-openrc.sh"
source /tmp/tacker/admin-openrc.sh
echo "$0: Setup Tacker user in OpenStack"
-openstack user create --password tacker tacker
+openstack user create --project services --password tacker tacker
openstack role add --project services --user tacker admin
echo "$0: Create Tacker service in OpenStack"
@@ -214,19 +223,22 @@ sed -i -- 's/# auth_strategy = keystone/auth_strategy = keystone/' /usr/local/et
sed -i -- 's/# debug = False/debug = True/' /usr/local/etc/tacker/tacker.conf
sed -i -- 's/# use_syslog = False/use_syslog = False/' /usr/local/etc/tacker/tacker.conf
sed -i -- 's~# state_path = /var/lib/tacker~state_path = /var/lib/tacker~' /usr/local/etc/tacker/tacker.conf
-sed -i -- 's/password = service-password/password=tacker/' /usr/local/etc/tacker/tacker.conf
-sed -i -- "s~auth_url = http://<KEYSTONE_IP>:35357~auth_url = http://$KEYSTONE_HOST:35357~" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s/project_name = service/project_name = services/g" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s/password = service-password/password = tacker/" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s/username = tacker/username = tacker/" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s~auth_url = http://127.0.0.1:35357~auth_url = http://$KEYSTONE_HOST:35357~" /usr/local/etc/tacker/tacker.conf
sed -i -- "s~identity_uri = http://127.0.0.1:5000~# identity_uri = http://127.0.0.1:5000~" /usr/local/etc/tacker/tacker.conf
-sed -i -- "s~auth_uri = http://<KEYSTONE_IP>:5000~auth_uri = http://$KEYSTONE_HOST:5000~" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s~auth_uri = http://127.0.0.1:5000~auth_uri = http://$KEYSTONE_HOST:5000~" /usr/local/etc/tacker/tacker.conf
# Not sure what the effect of the next line is, given that we are running as root
#sed -i -- "s~# root_helper = sudo~root_helper = sudo /usr/local/bin/tacker-rootwrap /usr/local/etc/tacker/rootwrap.conf~" /usr/local/etc/tacker/tacker.conf
-sed -i -- "s~# connection = mysql://root:pass@127.0.0.1:3306/tacker~connection = mysql://root:$MYSQL_PASSWORD@$ip:3306/tacker?charset=utf8~" /usr/local/etc/tacker/tacker.conf
-sed -i -- ":a;N;$!ba;s~password = service-password\nusername = nova\nauth_url = http://127.0.0.1:35357~password = $OS_PASSWORD\nauth_url = http://$NOVA_HOST:35357~g" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s~# connection = mysql://root:pass@127.0.0.1:3306/tacker~connection = mysql://root:$MYSQL_PASSWORD@localhost:3306/tacker?charset=utf8~" /usr/local/etc/tacker/tacker.conf
sed -i -- "s~heat_uri = http://localhost:8004/v1~heat_uri = http://$HEAT_HOST:8004/v1~" /usr/local/etc/tacker/tacker.conf
sed -i -- "s~# api_paste_config = api-paste.ini~api_paste_config = /tmp/tacker/tacker/etc/tacker/api-paste.ini~" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s/# bind_host = 0.0.0.0/bind_host = $ip/" /usr/local/etc/tacker/tacker.conf
+sed -i -- "s/# bind_port = 8888/bind_port = 9890/" /usr/local/etc/tacker/tacker.conf
echo "$0: Populate Tacker database"
-/tmp/tacker/venv/bin/tacker-db-manage --config-file /etc/tacker/tacker.conf upgrade head
+/usr/local/bin/tacker-db-manage --config-file /usr/local/etc/tacker/tacker.conf upgrade head
echo "$0: Install Tacker Client"
cd /tmp/tacker
@@ -247,6 +259,61 @@ python setup.py install
#service apache2 restart
echo "$0: Start the Tacker Server"
-python /tmp/tacker/venv/bin/tacker-server --config-file /usr/local/etc/tacker/tacker.conf --log-file /var/log/tacker/tacker.log
+python /usr/local/bin/tacker-server --config-file /usr/local/etc/tacker/tacker.conf --log-file /var/log/tacker/tacker.log & disown
+
+echo "$0: Register default VIM"
+cd /tmp/tacker
+cat <<EOF >vim-config.yaml
+auth_url: $OS_AUTH_URL
+username: $OS_USERNAME
+password: $OS_PASSWORD
+project_name: admin
+EOF
+tacker vim-register --config-file vim-config.yaml --description OpenStack --name VIM0
+
+echo "$0: Prepare Tacker test network environment"
+
+echo "Create management network"
+if [ $(neutron net-list | awk "/ tacker_mgmt / { print \$2 }") ]; then
+ echo "$0: tacker_mgmt network exists"
+else
+ neutron net-create tacker_mgmt
+ echo "$0: Create management subnet"
+ neutron subnet-create tacker_mgmt 192.168.200.0/24 --name tacker_mgmt --gateway 192.168.200.1 --enable-dhcp --allocation-pool start=192.168.200.2,end=192.168.200.254 --dns-nameserver 8.8.8.8
+fi
+
+echo "$0: Create router for cloudify_mgmt network"
+if [ $(neutron router-list | awk "/ tacker_mgmt / { print \$2 }") ]; then
+ echo "$0: tacker_mgmt router exists"
+else
+ neutron router-create tacker_mgmt_router
+ echo "$0: Add router interface for cloudify_mgmt network"
+ neutron router-interface-add tacker_mgmt_router subnet=tacker_mgmt
+fi
+
+echo "Create private network"
+if [ $(neutron net-list | awk "/ tacker_private / { print \$2 }") ]; then
+ echo "$0: tacker_private network exists"
+else
+ neutron net-create tacker_private
+ echo "$0: Create private subnet"
+ neutron subnet-create tacker_private 192.168.201.0/24 --name tacker_private --gateway 192.168.201.1 --enable-dhcp --allocation-pool start=192.168.201.2,end=192.168.201.254 --dns-nameserver 8.8.8.8
+fi
+
+echo "$0: Create router for cloudify_private network"
+if [ $(neutron router-list | awk "/ tacker_private / { print \$2 }") ]; then
+ echo "$0: tacker_private router exists"
+else
+ neutron router-create tacker_private_router
+ echo "$0: Create router gateway for cloudify_private network"
+ neutron router-gateway-set tacker_private_router $EXTERNAL_NETWORK_NAME
+ echo "$0: Add router interface for cloudify_private network"
+ neutron router-interface-add tacker_private_router subnet=tacker_private
+fi
+
+echo "$0: Create image cirros-0.3.4-x86_64-uec"
+image=$(openstack image list | awk "/ cirros-0.3.4-x86_64-uec / { print \$2 }")
+if [ -z $image ]; then glance --os-image-api-version 1 image-create --name cirros-0.3.4-x86_64-uec --disk-format qcow2 --location http://download.cirros-cloud.net/0.3.3/cirros-0.3.3-x86_64-disk.img --container-format bare
+fi
+
-# Registering default VIM: deferrred
@@ -19,11 +19,12 @@
# tacker-cli: use Tacker CLI
# tacker-api: use Tacker RESTful API
-# 1: Initial setup of the docker container
-# 2: Setup of Tacker in the docker container
+# init: Initialize docker container
+# setup: Setup of Tacker in the docker container
+# clean: Clean
function setenv () {
if [ "$dist" == "Ubuntu" ]; then